@@ -40,6 +40,9 @@ use 5.012;
 use strict;
 use warnings;
 
+use Exporter 'import';
+use Time::Piece;
+use Time::Seconds;
 
 
 
@@ -52,11 +55,11 @@ App::Dochazka - Dochazka Attendance and Time Tracking System shared modules
 
 =head1 VERSION
 
-Version 0.188
+Version 0.189
 
 =cut
 
-our $VERSION = '0.188';
+our $VERSION = '0.189';
 
 
 
@@ -68,6 +71,42 @@ L<App::Dochazka::REST> and the command-line client L<App::Dochazka::CLI>.
 
 =cut
 
+
+
+=head1 PACKAGE VARIABLES AND EXPORTS
+
+=cut
+
+our ( $t, $today, $yesterday, $tomorrow );
+
+our @EXPORT_OK = qw( 
+    $t
+    $today
+    $yesterday
+    $tomorrow
+    init_timepiece
+);
+
+
+
+=head1 FUNCTIONS
+
+
+=head2 init_timepiece
+
+(Re-)initialize the date/time-related package variables
+
+=cut
+
+sub init_timepiece {
+    #print "Entering " . __PACKAGE__ . "::init_timepiece\n";
+    $t = localtime;
+    $today = $t->ymd;
+    $yesterday = ($t - ONE_DAY)->ymd;
+    $tomorrow = ($t + ONE_DAY)->ymd;
+}
+
+
 1;
 
 
